# Installing from PyPI

To install TuxMake on your system globally:

```
sudo pip3 install -U tuxmake
```

To install tuxbuild to your home directory at ~/.local/bin:

```
pip3 install -U --user tuxmake
```

To upgrade TuxMake to the latest version, run the same command you ran to
install it.
